aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJohan Gardsmark <johan.gardsmark@stericsson.com>2011-02-21 13:52:35 +0100
committerHenrik Öhman <henrik.ohman@stericsson.com>2011-03-11 10:14:11 +0100
commit5cfe53f2affd44f280b75e7bdf3da4461a66e2c8 (patch)
treed0690b7bd8163df63cc00963ab9b31810a5b557a /include
parentd74ad6edacff6eb1317cb207afb17940b5af41de (diff)
ARM: ux500: Move board specific bm parameters
This patch moves the board specific charger and battery parameters to a separate file. Also, some parameter names are corrected and simplified. ST-Ericsson ID: WP325165 Change-Id: I90aedb1b623f85f1c877afbe44aa8c802f5fd640 Signed-off-by: Johan Gardsmark <johan.gardsmark@stericsson.com> Reviewed-on: http://gerrit.lud.stericsson.com/gerrit/16609 Reviewed-by: Johan PALSSON <johan.palsson@stericsson.com> Reviewed-by: Jonas ABERG <jonas.aberg@stericsson.com>
Diffstat (limited to 'include')
-rw-r--r--include/linux/mfd/ab8500/ab8500-bm.h50
1 files changed, 23 insertions, 27 deletions
diff --git a/include/linux/mfd/ab8500/ab8500-bm.h b/include/linux/mfd/ab8500/ab8500-bm.h
index d99a150f992..c3a8b291dd3 100644
--- a/include/linux/mfd/ab8500/ab8500-bm.h
+++ b/include/linux/mfd/ab8500/ab8500-bm.h
@@ -226,15 +226,15 @@
#define BATTERY_UNKNOWN 00
/*
* Thermistor location.
* When using the THERM_BATTERY_PACK the battery ID resistor is combined with
* a NTC resistor to both identify the battery and to measure its temperature.
* Different phone manufactures uses different techniques to both identify the
* battery and to read its temperature.
*/
-enum thermistor {
- THERM_BATTERY_PACK,
- THERM_PCB,
+enum adc_therm {
+ ADC_THERM_BATCTRL,
+ ADC_THERM_BATTEMP,
};
/**
@@ -297,16 +297,16 @@ struct ab8500_fg_parameters {
* @charge_full_design: Maximum battery capacity in mAh
* @nominal_voltage: Nominal voltage of the battery in mV
* @termination_vol: max voltage upto which battery can be charged
* @normal_op_cur_lvl: charger current in normal state in mA
* @normal_ip_vol_lvl: charger voltage in normal state in mV
* @maint_a_op_cur_lvl: charger current in maintenance A state in mA
* @maint_a_ip_vol_lvl: charger voltage in maintenance A state in mV
* @maint_a_chg_timer_h: charge time in maintenance A state
* @maint_b_op_cur_lvl: charger current in maintenance B state in mA
* @maint_b_ip_vol_lvl: charger voltage in maintenance B state in mV
* @maint_b_chg_timer_h: charge time in maintenance B state
* @low_high_op_cur_lvl: charger current in temp low/high state in mA
* @low_high_ip_vol_lvl: charger voltage in temp low/high state in mV'
* @battery_resistance: battery inner resistance in mOhm.
* @n_r_t_tbl_elements: number of elements in r_to_t_tbl
* @r_to_t_tbl: table containing resistance to temp points
@@ -321,16 +321,16 @@ struct battery_type {
int nominal_voltage;
int termination_vol;
int termination_curr;
- int normal_op_cur_lvl;
- int normal_ip_vol_lvl;
- int maint_a_op_cur_lvl;
- int maint_a_ip_vol_lvl;
+ int normal_cur_lvl;
+ int normal_vol_lvl;
+ int maint_a_cur_lvl;
+ int maint_a_vol_lvl;
int maint_a_chg_timer_h;
- int maint_b_op_cur_lvl;
- int maint_b_ip_vol_lvl;
+ int maint_b_cur_lvl;
+ int maint_b_vol_lvl;
int maint_b_chg_timer_h;
- int low_high_op_cur_lvl;
- int low_high_ip_vol_lvl;
+ int low_high_cur_lvl;
+ int low_high_vol_lvl;
int battery_resistance;
int n_temp_tbl_elements;
struct res_to_temp *r_to_t_tbl;
@@ -378,14 +378,12 @@ struct ab8500_bm_charger_parameters {
* @usb_safety_tmr_h safety timer for usb charger
* @bkup_bat_v voltage which we charge the backup battery with
* @bkup_bat_i current which we charge the backup battery with
- * @therm placement of thermistor, inside or outside of batt pack
+ * @adc_therm placement of thermistor, batctrl or battemp adc
* @chg_unknown_bat flag to enable charging of unknown batteries
* @fg_res resistance of FG resistor in mOhm
* @n_btypes number of elements in array bat_type
- * @n_temp_tbl_elements number of elements in array pcb_ntc
* @batt_id index of the identified battery in array bat_type
* @cap_levels capacity in percent for the different capacity levels
- * @pcb_ntc table with resistance to temp for PCB mounted NTC
* @bat_type table of supported battery types
* @chg_params charger parameters
* @fg_params fuel gauge parameters
@@ -400,13 +398,11 @@ struct ab8500_bm_data {
int bkup_bat_v;
int bkup_bat_i;
bool chg_unknown_bat;
- enum thermistor therm;
+ enum adc_therm adc_therm;
int fg_res;
int n_btypes;
- int n_temp_tbl_elements;
int batt_id;
struct ab8500_bm_capacity_levels *cap_levels;
- struct res_to_temp *pcb_ntc;
struct battery_type *bat_type;
const struct ab8500_bm_charger_parameters *chg_params;
const struct ab8500_fg_parameters *fg_params;
@@ -226,15 +226,15 @@
#define BATTERY_UNKNOWN 00
/*
- * Thermistor location.
- * When using the THERM_BATTERY_PACK the battery ID resistor is combined with
+ * ADC for the battery thermistor.
+ * When using the ADC_THERM_BATCTRL the battery ID resistor is combined with
* a NTC resistor to both identify the battery and to measure its temperature.
* Different phone manufactures uses different techniques to both identify the
@@ -297,16 +297,16 @@ struct ab8500_fg_parameters {
* @nominal_voltage: Nominal voltage of the battery in mV
* @termination_vol: max voltage upto which battery can be charged
- * @normal_op_cur_lvl: charger current in normal state in mA
- * @normal_ip_vol_lvl: charger voltage in normal state in mV
- * @maint_a_op_cur_lvl: charger current in maintenance A state in mA
- * @maint_a_ip_vol_lvl: charger voltage in maintenance A state in mV
+ * @normal_cur_lvl: charger current in normal state in mA
+ * @normal_vol_lvl: charger voltage in normal state in mV
+ * @maint_a_cur_lvl: charger current in maintenance A state in mA
+ * @maint_a_vol_lvl: charger voltage in maintenance A state in mV
* @maint_a_chg_timer_h: charge time in maintenance A state
@@ -297,16 +297,16 @@ struct ab8500_fg_parameters {
* @maint_a_chg_timer_h: charge time in maintenance A state
- * @maint_b_op_cur_lvl: charger current in maintenance B state in mA
- * @maint_b_ip_vol_lvl: charger voltage in maintenance B state in mV
+ * @maint_b_cur_lvl: charger current in maintenance B state in mA
+ * @maint_b_vol_lvl: charger voltage in maintenance B state in mV
* @maint_b_chg_timer_h: charge time in maintenance B state
@@ -297,16 +297,16 @@ struct ab8500_fg_parameters {
* @maint_b_chg_timer_h: charge time in maintenance B state
- * @low_high_op_cur_lvl: charger current in temp low/high state in mA
- * @low_high_ip_vol_lvl: charger voltage in temp low/high state in mV'
+ * @low_high_cur_lvl: charger current in temp low/high state in mA
+ * @low_high_vol_lvl: charger voltage in temp low/high state in mV'
* @battery_resistance: battery inner resistance in mOhm.
* @n_r_t_tbl_elements: number of elements in r_to_t_tbl